"""Kbl group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

KBL_TASKS = {
    "kbl": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2012": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2013": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2015": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2017": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2020": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2022": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2023": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_civil_2025": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2012": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2013": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2015": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2017": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2020": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2022": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2023": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_criminal_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2012": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2013": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2015": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2017": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2020": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2022": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2023": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_bar_exam_em_public_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_civil": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_civil_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_civil_2025": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_criminal": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_criminal_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_criminal_2025": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_public": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_public_2024": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_legal_bar_exam_public_2025": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_civil_2023": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_criminal_2023": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2014": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2016": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2018": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2019": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2021": f"{BASE_IMPORT}kbl:KblExtractor",
    "kbl_leet_public_2023": f"{BASE_IMPORT}kbl:KblExtractor",
}
